@@ -3,21 +3,13 @@
 tibble::as_tibble
 
 #' @exportS3Method
-as.data.frame.rmd_ast = function(x, ..., include_yaml = TRUE) {
-  as_tibble.rmd_ast(x, include_yaml)
-}
-
-#' @exportS3Method
-as_tibble.rmd_ast = function(x, include_yaml = TRUE, ...) {
-
-  if (!include_yaml & inherits(x[[1]], "rmd_yaml"))
-    x = x[-1]
+as_tibble.rmd_ast = function(x, ...) {
 
   df = tibble::as_tibble( list(
     sections = rmd_node_sections(x, drop_na = FALSE),
     type = rmd_node_type(x),
     label = rmd_node_label(x),
-    ast = x
+    ast = x@nodes
   ) )
 
   df = tidyr::unnest_wider(df, tidyselect::all_of("sections"))
@@ -30,46 +22,52 @@ as_tibble.rmd_ast = function(x, include_yaml = TRUE, ...) {
 #' @importFrom pillar type_sum
 pillar::type_sum
 
-#' @export
+#' @exportS3Method
 type_sum.rmd_chunk = function(x) {
   paste(
     cli::style_bold("chunk"),
-    #cli::style_italic('"', x$name, '"')
-    paste0("[", x$engine, "]")
+    #cli::style_italic('"', x@name, '"')
+    paste0("[", x@engine, "]")
   )
 }
 
-#' @export
+#' @exportS3Method
 type_sum.rmd_raw_chunk = function(x) {
   paste(
     cli::style_bold("raw attr chunk"),
-    paste0("[", x$format, "]")
+    paste0("[", x@format, "]")
   )
 }
 
-#' @export
+#' @exportS3Method
 type_sum.rmd_yaml = function(x) {
-  paste(
-    cli::style_bold("yaml"),
-  )
+  cli::style_bold("yaml")
 }
 
-#' @export
+#' @exportS3Method
 type_sum.rmd_heading = function(x) {
   paste(
     cli::style_bold("heading"),
-    paste0("[h", x$level, "]")
+    paste0("[h", x@level, "]")
   )
 }
 
-#' @export
-type_sum.rmd_yaml_list = function(x) {
-  paste(
-    cli::style_bold("yaml")
-  )
-}
-
-#' @export
+#' @exportS3Method
 type_sum.rmd_markdown = function(x) {
   cli::style_bold("markdown")
 }
+
+#' @exportS3Method
+type_sum.rmd_code_block = function(x) {
+  cli::style_bold("code block")
+}
+
+#' @exportS3Method
+type_sum.rmd_fenced_div_open = function(x) {
+  cli::style_bold("fdiv [open]")
+}
+
+#' @exportS3Method
+type_sum.rmd_fenced_div_close = function(x) {
+  cli::style_bold("fdiv [close]")
+}
