@@ -1,5 +1,5 @@
 test_that("check output - with content", {
-  ast = parse_rmd(system.file("hw02-complex.Rmd", package="parsermd"))
+  ast = parse_rmd(system.file("examples/hw02-complex.Rmd", package="parsermd"))
   ans = rmd_select(ast, by_section(c("Exercise *", "Answer")))
   template = rmd_template(ans, keep_content = TRUE)
 
@@ -10,7 +10,7 @@ test_that("check output - with content", {
 })
 
 test_that("check output - without content", {
-  ast = parse_rmd(system.file("hw02-complex.Rmd", package="parsermd"))
+  ast = parse_rmd(system.file("examples/hw02-complex.Rmd", package="parsermd"))
   ans = rmd_select(ast, by_section(c("Exercise *", "Answer")))
   template = rmd_template(ans, keep_content = FALSE)
 
